JepException
Date: 2017-11-20

jep

## Class JepException

- java.lang.Object
- - java.lang.Throwable
  - - java.lang.Exception
    - - jep.JepException

- All Implemented Interfaces:
    java.io.Serializable

      public class JepException
      extends java.lang.Exception

  JepException - it happens.
  See Also:
    Serialized Form

- - ### Constructor Summary

    Constructors
    Modifier | Constructor and Description
    --- | ---
    `` | `JepException()` Creates a new `JepException` instance.
    `` | `JepException(java.lang.String s)` Creates a new `JepException` instance.
    `protected` | `JepException(java.lang.String s, long pythonType)` Construct with the address of a python exception type.
    `` | `JepException(java.lang.String s, java.lang.Throwable t)` Creates a new `JepException` instance.
    `` | `JepException(java.lang.Throwable t)` Creates a new `JepException` instance.

  - ### Method Summary

    All Methods Instance Methods Concrete Methods
    Modifier and Type | Method and Description
    --- | ---
    `protected long` | `getPythonType()` Get the address of the python exception type that triggered this exceptions.

    - ### Methods inherited from class java.lang.Throwable

      `addSuppressed, fillInStackTrace, getCause, getLocalizedMessage, getMessage, getStackTrace, getSuppressed, initCause, printStackTrace, printStackTrace, printStackTrace, setStackTrace, toString`

    - ### Methods inherited from class java.lang.Object

      `clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait`

- - ### Constructor Detail

    - #### JepException

          public JepException()

      Creates a new `JepException` instance.

    - #### JepException

          public JepException(java.lang.String s)

      Creates a new `JepException` instance.
      Parameters:
        `s` - a `String` value

    - #### JepException

          public JepException(java.lang.Throwable t)

      Creates a new `JepException` instance.
      Parameters:
        `t` - a `Throwable` value

    - #### JepException

          public JepException(java.lang.String s,
                              java.lang.Throwable t)

      Creates a new `JepException` instance.
      Parameters:
        `s` - a `String` value
        `t` - a `Throwable` value

    - #### JepException

          protected JepException(java.lang.String s,
                                 long pythonType)

      Construct with the address of a python exception type. This is for internal use only.

  - ### Method Detail

    - #### getPythonType

          protected long getPythonType()

      Get the address of the python exception type that triggered this exceptions. This is for internal use only.